@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
+// SPDX-License-Identifier: GPL-2.0
+/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
  *
  * Marek Lindner <mareklindner@neomailbox.ch>, Simon Wunderlich
  *
@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 #include "icmp_helper.h"
@@ -39,12 +40,12 @@
 #include <sys/uio.h>
 #include <unistd.h>
 
+#include "batadv_packet.h"
 #include "debug.h"
 #include "debugfs.h"
 #include "functions.h"
 #include "list.h"
 #include "netlink.h"
-#include "packet.h"
 
 #ifndef ETH_P_BATMAN
 #define ETH_P_BATMAN	0x4305
