@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
+/* SPDX-License-Identifier: GPL-2.0 */
+/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 #ifndef _BATCTL_MAIN_H
@@ -25,7 +26,7 @@
 #include <stdint.h>
 
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION "2017.2"
+#define SOURCE_VERSION "2018.0"
 #endif
 
 #define SOCKET_PATH_FMT "%s/batman_adv/%s/socket"
@@ -46,14 +47,9 @@
 #error "unknown endianess"
 #endif
 
-#define __packed __attribute((packed))   /* linux kernel compat */
 #define __maybe_unused __attribute__((unused))
 #define BIT(nr)                 (1UL << (nr)) /* linux kernel compat */
 
-typedef uint8_t u8; /* linux kernel compat */
-typedef uint16_t u16; /* linux kernel compat */
-typedef uint32_t u32; /* linux kernel compat */
-
 extern char module_ver_path[];
 
 #ifndef VLAN_VID_MASK
