@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
+// SPDX-License-Identifier: GPL-2.0
+/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 
@@ -36,10 +37,10 @@
 #include <sys/time.h>
 #include <netinet/if_ether.h>
 
+#include "batadv_packet.h"
 #include "main.h"
 #include "ping.h"
 #include "functions.h"
-#include "packet.h"
 #include "bat-hosts.h"
 #include "debugfs.h"
 #include "icmp_helper.h"
