@@ -1,5 +1,5 @@
-/*
- * Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
+// SPDX-License-Identifier: GPL-2.0
+/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -17,6 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301, USA
  *
+ * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
 
@@ -33,10 +34,10 @@
 #include <sys/select.h>
 #include <sys/time.h>
 
+#include "batadv_packet.h"
 #include "main.h"
 #include "traceroute.h"
 #include "functions.h"
-#include "packet.h"
 #include "bat-hosts.h"
 #include "debugfs.h"
 #include "icmp_helper.h"
@@ -150,7 +151,7 @@ int traceroute(char *mesh_iface, int argc, char **argv)
 					   (struct batadv_icmp_header *)&icmp_packet_out,
 					   sizeof(icmp_packet_out));
 			if (res < 0) {
-				fprintf(stderr, "Error - can't send icmp packet: %s\n", strerror(res));
+				fprintf(stderr, "Error - can't send icmp packet: %s\n", strerror(-res));
 				continue;
 			}
 
